/*=============================================================================
Vitalnix/C-spark - User Management CLI/CUI
autorun.c
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
  -- License restrictions apply (Dual FAL/GPL2)
  -- For details see doc/FAL.txt and doc/GPL2.txt.
  $Id: autorun.c,v 1.3 2004/05/11 13:47:03 hirogen2 Exp $
=============================================================================*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <libHX.h>
#include <accdb.h>
#include "global.h"

inline static void autorun_init(void);

static int k_ran = 0;

//-----------------------------------------------------------------------------
// "Internal" autorun functions

inline static void autorun_init(void) {
    ++k_ran;
    return;
}

int autorun_sd(void) { return k_ran; }

//-----------------------------------------------------------------------------
// Password list printing (-P)

void autorun_pwl(char *arg) {
    char *style, *infile, *outfile;
    autorun_init();
    printf("\n" "Autorun command: `%s`\n", arg);

    style   = HX_strsep(&arg, ":"); // XXX case `style==NULL` possible?
    infile  = HX_strsep(&arg, ":");
    outfile = HX_strsep(&arg, ":");

    if(*style == '\0') { style = "sg"; }
    if(*style == '?' || strcmp(style, "-?") == 0 ||
     stricmp(style, "HELP") == 0) {
        pwl_styles();
        return;
    }

    if(infile == NULL || *infile == '\0' || outfile == NULL ||
     *outfile == '\0') {
        fprintf(stderr, "-P argument malformed. Should be -P"
         " style:infile:outfile!\n");
        exit(EXIT_FAILURE);
    }

    pwl_proc(style, infile, outfile);
    return;
}

//-----------------------------------------------------------------------------
// Synchronization (-S)

void autorun_sync(char *arg) {
    struct HXbtree *addl = NULL, *lnlist = NULL;
    struct HXlld *dell = NULL;
    struct accdb_group dgroup;
    char *gname, *infile, *outfile;
    FILE *logp = NULL;

    autorun_init();
    printf("\n" "Autorun command: `%s`\n", arg);

    gname   = HX_strsep(&arg, ":");
    infile  = HX_strsep(&arg, ":");
    outfile = HX_strsep(&arg, ":");

    if(gname == NULL || infile == NULL) {
        // Leaving outfile == NULL out intentionally
        fprintf(stderr, "-S argument malformed. Should be -S"
         " group:infile:logfile!\n");
        exit(EXIT_FAILURE);
    }

    if(outfile == NULL) { outfile = ""; } // XXX: Does this work everywhere?

    if(!Q_OPEN()) { exit(EXIT_FAILURE); }
    if(!sync_prep_dgrp(&dgroup, gname) || !sync_read_file(infile, &addl)) {
        goto out;
    }

    sync_compare(&dgroup, addl, &dell, &lnlist);
    if(addl->itemcount == 0 && dell->itemcount == 0) {
        printf("Already synchronized\n");
        goto out;
    }

    sync_fixup_addl(addl, lnlist);
    sync_set_aflush();
    if(*outfile != '\0' && (logp = sync_open_log(outfile, 'w')) == NULL) {
        goto out;
    }

    if(addl->itemcount > 0 && !sync_add(&dgroup, addl, logp)) {
        printf("Error during operation. You might need to redo the"
         " Synchronization process\n" "to complete all jobs.\n");
        goto out2;
    }

    if(dell->itemcount > 0 && !sync_del(dell, logp)) {
        printf("Error during operation. You might need to redo the"
         " Synchronization process\n" "to complete all jobs.\n");
        goto out;
    }

out2:
    Q_SYSCTL(ACCDB_FLUSHDB);

out:
    if(logp != NULL) { fclose(logp); }
    sync_free(addl, dell);
    Q_CLOSE();
    return;
}

//-----------------------------------------------------------------------------
// Adding a single user (-U)

void autorun_user(char *arg) {
    char *nname, *vname, *bday, *sgroup;
    autorun_init();

    nname  = HX_strsep(&arg, ":");
    vname  = HX_strsep(&arg, ":");
    bday   = HX_strsep(&arg, ":");
    sgroup = HX_strsep(&arg, ":");

    if(nname == NULL || vname == NULL) { }
    return;
}

//==[ End of file ]============================================================
