/*=============================================================================
Vitalnix/ACCDB - Unified Account Database
include/accdb.h - Include file for ACCDB back-end mod.s or apps utilizing them
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003 - 2004
  -- License restrictions apply (Dual FAL/LGPL2)
  -- For details see doc/FAL.txt and doc/LGPL2.txt.
  $Id: accdb.h,v 1.10 2004/04/24 14:31:25 hirogen2 Exp $
=============================================================================*/
#ifndef _ACCDB_H
#define _ACCDB_H 1

#include <sys/types.h>

#ifdef __cplusplus
extern "C" {
#endif

struct accdb_user {
    // passwd part
    char *lname;
    long uid, gid;
    char *gecos, *home, *shell, *igrp, *sgrp;

    // shadow part
    char *passwd;
    long last_change, keep_min, keep_max, warn_age, expire, inactive;
    void *_private;
};

struct accdb_group {
    char *gname;
    long gid;
    void *_private;
};

struct accdb_module {
    const char *name, *desc, *info;
    void *handle, *state;
    int (*init)(struct accdb_module *, const char *);
    int (*open)(struct accdb_module *);
    int (*usertrav)(struct accdb_module *, struct accdb_user *);
    int (*userinfo)(struct accdb_module *, struct accdb_user *, struct accdb_user *, size_t);
    int (*useradd)(struct accdb_module *, struct accdb_user *);
    int (*usermod)(struct accdb_module *, struct accdb_user *, struct accdb_user *);
    int (*userdel)(struct accdb_module *, struct accdb_user *);
    int (*grouptrav)(struct accdb_module *, struct accdb_group *);
    int (*groupinfo)(struct accdb_module *, struct accdb_group *, struct accdb_group *, size_t);
    int (*groupadd)(struct accdb_module *, struct accdb_group *);
    int (*groupmod)(struct accdb_module *, struct accdb_group *, struct accdb_group *);
    int (*groupdel)(struct accdb_module *, struct accdb_group *);
    int (*close)(struct accdb_module *);
    long (*sysctl)(unsigned int, ...);
    void (*deinit)(struct accdb_module *);
};

struct rconfig_opt {
    const char *key;
    unsigned char type;
    void *ptr;
    int (*callback)(const char *, unsigned char, void *, void *);
    void *uptr;
};

enum accdb_crypt_meth {
    CRYPW_DES = 1,
    CRYPW_MD5,
    CRYPW_BLOWFISH,
};

struct accdb_cryptinfo {
    // Input fields
    unsigned char *key;
    int method;

    // Output fields
    unsigned char *crypted;
};

enum {
    GENPW_PHONEMIC  = 1 << 0,
    GENPW_ONE_DIGIT = 1 << 1,
    GENPW_ONE_CASE  = 1 << 2,
};

enum {
    RCONFIG_ONE  = 1 << 0, // only read one configuration file

    RCONF_BYTE = 1,
    RCONF_UCHAR,
    RCONF_CHAR,
    RCONF_USHORT,
    RCONF_SHORT,
    RCONF_UINT,
    RCONF_INT,
    RCONF_ULONG,
    RCONF_LONG,
    RCONF_FLOAT,
    RCONF_DOUBLE,
    RCONF_BOOL,
    RCONF_IBOOL,
    RCONF_STRING,
    RCONF_CB,
    RCONF_ULLONG,
    RCONF_LLONG,
};

enum {
    ACCDB_AFLUSH = 1 << 0,
};

enum accdb_sysctl_req {
    ACCDB_ADDFLAGS = 0x1,
    ACCDB_DELFLAGS,
    ACCDB_FLUSHDB,
    ACCDB_COUNT_USERS,
    ACCDB_COUNT_GROUPS,

    ACCDB_NEXTUID_SYS = 0x100,
    ACCDB_NEXTUID,
    ACCDB_NEXTGID_SYS,
    ACCDB_NEXTGID,

    ACCDB_LOCK_EXCL = 0xA000,
    ACCDB_UNLOCK_EXCL,

    // module specific sysctl requests shall start at 0xC000
};

extern struct accdb_module *accdb_load(const char *);
extern void accdb_unload(struct accdb_module *);
extern int accdb_genpw(char *, size_t, unsigned long);
extern int accdb_cryptpw(const char *, const char *, int, char **);
extern int accdb_rconfig(const char *, struct rconfig_opt *);
extern int accdb_rconfig_pv(const char **, const char *, struct rconfig_opt *,
 unsigned long);
extern void accdb_rconfig_free(struct rconfig_opt *);

#ifdef __cplusplus
} // extern "C"
#endif

#endif /* _ACCDB_H */

//==[ End of file ]============================================================
