/*=============================================================================
Vitalnix/ACCDB - Unified Account Database
sysprog/id.c - Print real and effective UIDs and GIDs
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003 - 2004
  -- License restrictions apply (Dual FAL/GPL2)
  -- For details see doc/FAL.txt and doc/GPL2.txt.
  $Id: id.c,v 1.1 2004/05/11 13:39:54 hirogen2 Exp $
=============================================================================*/
#include <sys/types.h>
#include <errno.h>
#include <popt.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <libHX.h>
#include <accdb.h>
#include "sysprog/shared.h"

static struct {
    int only_grp, only_groups, only_user, print_name, print_real;
} opt = {
    only_grp: 0, only_groups: 0, only_user: 0, print_name: 0, print_real: 0,
};

static int get_options(int *, const char ***);

static char *module_path = "*";

//-----------------------------------------------------------------------------
int main(int argc, char **argv) {
    struct accdb_module *db;
    struct accdb_user mask;
    int i_stage = 0;
    int eax;
    char *lu_name;
    uid_t lu_id;

    if(!(eax = get_options(&argc, (const char ***)&argv))) {
        return EXIT_FAILURE;
    }

    eax = opt.only_grp + opt.only_groups + opt.only_user;
    if(eax > 1) {
        fprintf(stderr, "id: Invalid argument combination (only one of -Ggu"
         " might be specified)\n");
        return EXIT_FAILURE;
    } else if(!eax && opt.print_real + opt.print_name) {
        fprintf(stderr, "id: Cannot print only names or real IDs in default"
         " format\n");
        return EXIT_FAILURE;
    }

    if(*argv != NULL) {
        // UNFINISHED
    }

    // ----------------------------------------
    if((db = accdb_load(module_path)) != NULL) {
        ++i_stage;
        if(db->open(db) > 0) {
            ++i_stage;
            memset(&mask, 0, sizeof(struct accdb_user));
        }
    }

    // ----------------------------------------
/*    if((eax = db->userinfo(db, &smask, NULL, 0)) < 0) {
        fprintf(stderr, "Error querying the ACCDB: %s (eax=%d, errno=%d)\n",
         strerror(errno), eax, errno);
        rv = E_OTHER;
        goto __main__close_backend;
    } else if(eax > 0) {
        fprintf(stderr, "User \"%s\" already exists\n", smask.lname);
        rv = E_NAME_USED;
        goto __main__close_backend;
    }
*/
    // ----------------------------------------
/*    if(Sh_only_digits(opt.igrp)) {
        mmask.gid  = strtoul(opt.igrp, NULL, 0);
        mmask.igrp = NULL;
    } else {
        mmask.gid  = -1;
        mmask.igrp = opt.igrp;
    }
*/
    // ----------------------------------------
    if(i_stage == 2) { db->close(db); --i_stage; }
    if(i_stage == 1) { accdb_unload(db); --i_stage; }
    return EXIT_SUCCESS;
}

//-----------------------------------------------------------------------------
static int get_options(int *argc, const char ***argv) {
    static const char *_empty_argv[] = {NULL};
    struct poptOption options_table[] = {
        {"groups", 'G', POPT_ARG_NONE, &opt.only_groups, '\0',
         "Print all group IDs", NULL},
        {"group", 'g', POPT_ARG_NONE, &opt.only_grp, '\0',
         "Print only the effective group ID", NULL},
        {"name", 'n', POPT_ARG_NONE, &opt.print_name, '\0',
         "Print a name instead of a number, for -Ggu", NULL},
        {"real", 'r', POPT_ARG_NONE, &opt.print_real, '\0',
         "Print the real ID instead of the effective ID, with -Ggu", NULL},
        {"user", 'u', POPT_ARG_NONE, &opt.only_user, '\0',
         "Print only the effective user ID", NULL},
        POPT_AUTOHELP
        POPT_TABLEEND
    };

    poptContext ctx;
    const char **args;
    int c, argk;

    ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
    while((c = poptGetNextOpt(ctx)) >= 0);
    if(c < -1) {
        fprintf(stderr, "id: %s: %s\n",
         poptBadOption(ctx, 0), poptStrerror(c));
        poptFreeContext(ctx);
        return 0;
    }

    if((args = poptGetArgs(ctx)) != NULL) {
        argk = Sh_count_args(args);
        poptDupArgv(argk, args, argc, argv);
    } else {
        *argc = 0;
        *argv = _empty_argv;
    }

    poptFreeContext(ctx);
    return 1;
}

//==[ End of file ]============================================================
