/*=============================================================================
Vitalnix - User Management Suite
sysprog/shared.c - Shared functions for the ACCDB system utilities
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003 - 2004
  -- License restrictions apply (Dual FAL/LGPL2)
  -- For details see doc/FAL.txt and doc/LGPL2.txt.
  $Id: shared.c,v 1.11 2004/05/11 14:07:03 hirogen2 Exp $
=============================================================================*/
#include <sys/stat.h>
#include <sys/types.h>
#include <fcntl.h>
#include <ctype.h>
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <unistd.h>

#include <libHX.h>
#include "sysprog/shared.h"
#ifndef O_BINARY
#    define O_BINARY 0
#endif

//-----------------------------------------------------------------------------
int Sh_count_args(const char **args) {
    int argk = 0;
    while(*args++ != NULL) { ++argk; }
    return argk;
}

void Sh_interactive(struct itab *qtabp) {
    char buf[MAXLNLEN];

    while(qtabp->fmt != NULL) {
        if(qtabp->type == 's') {
            char **ptr = qtabp->ptr;
            printf(qtabp->fmt, (*ptr != NULL) ? *ptr : "");
            fflush(stdout);
            fgets(buf, MAXLNLEN, stdin);
            HX_chomp(buf);
            if(*buf != '\0') { HX_strclone(ptr, buf); }
        } else if(qtabp->type == 'd') {
            int *ptr = qtabp->ptr;
            printf(qtabp->fmt, (ptr != NULL) ? *ptr : 0);
            fflush(stdout);
            fgets(buf, MAXLNLEN, stdin);
            HX_chomp(buf);
            if(*buf != '\0') { *ptr = strtol(buf, NULL, 0); }
        }

        if(!(qtabp->callback != NULL &&
         !qtabp->callback(qtabp->fmt, qtabp->type, qtabp->ptr))) {
            ++qtabp;
        }
    }

    return;
}

long Sh_string_to_iday(char *s) {
    struct tm td;
    time_t r;
    memset(&td, 0, sizeof(struct tm));

    if(strchr(s, '.') != NULL) {
        // DD.MM.YYYY
        sscanf(s, "%d.%d.%d", &td.tm_mday, &td.tm_mon, &td.tm_year);
    } else if(strchr(s, '/') != NULL) {
        // MM/DD/YYYY
        sscanf(s, "%d/%d/%d", &td.tm_mon, &td.tm_mday, &td.tm_year);
    } else if(strchr(s, '-') != NULL) {
        // YYYY-MM-DD (ISO 8601) format
        sscanf(s, "%d-%d-%d", &td.tm_year, &td.tm_mon, &td.tm_mday);
    } else {
        return -1;
    }

    r = mktime(&td);
    if(r == -1) { return -1; }
    return (unsigned long)r / 86400;
}

int Sh_only_digits(char *p) {
    if(p == NULL) { return 0; }
    while(*p != '\0') {
        if(!isdigit(*p++)) { return 0; }
    }
    return 1;
}

//==[ End of file ]============================================================
